# Bank Feeds
    
﻿Bank Feeds API enables your SMB users to set up bank feeds from accounts in your application to supported accounting platforms.

<!-- Start SDK Installation -->
<!-- End SDK Installation -->
    
## Example Usage
<!-- Start SDK Example Usage -->
<!-- End SDK Example Usage -->

<!-- Start SDK Available Operations -->
<!-- End SDK Available Operations -->
### Library generated by [Speakeasy](https://docs.speakeasyapi.dev/docs/using-speakeasy/client-sdks)
